<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d baglantı';
$lang['%d associations'] = '%d baglantılar';
$lang['%d album including'] = '%d albüm dahil';
$lang['%d albums including'] = '%d albümler dahil';
$lang['%d physical'] = ' %d fiziksel';
$lang[' and %d virtual'] = ' ve %d sanal';
$lang['%d album moved'] = '%d albüm taşındı';
$lang['%d albums moved'] = '%d albümler taşındı';
$lang['%d group'] = '%d grup';
$lang['%d groups'] = '%d gruplar';
$lang['%d member'] = '%d üye';
$lang['%d members'] = '%d üyeler';
$lang['%d tag'] = '%d etiket';
$lang['%d tags'] = '%d etiketler';
$lang['%d user comment rejected'] = '%d kullanıcı yorumu reddedildi.';
$lang['%d user comments rejected'] = '%d kullanıcı yorumlari reddedildi';
$lang['%d user comment validated'] = '%d kullanıcı yorumu onaylandi';
$lang['%d user comments validated'] = '%d kullanıcı yorumlari onaylandi';
$lang['%d user deleted'] = '%d kullanıcı silindi';
$lang['%d users deleted'] = '%d kullanıcılar silindi';
$lang['%d user'] = '%d kullanıcı';
$lang['%d users'] = '%d kullanıcılar';
$lang['%d waiting for validation'] = '%d onay bekleniyor';
$lang['Actions'] = 'Aksiyonlar';
$lang['Activate'] = 'Aktif';
$lang['Add/delete a permalink'] = 'Kalıcı Bağlantı ekle / sil';
$lang['Add a tag'] = 'Etiket ekle';
$lang['Add a user'] = 'Kullanıcı ekle';
$lang['Add group'] = 'Grup ekle';
$lang['Add'] = 'Ekle';
$lang['Allow user registration'] = 'Kullanıcı kaydına izin ver';
$lang['Apply to sub-albums'] = 'altalbümlere uygula';
$lang['Associated'] = 'baglantili';
$lang['Batch management'] = 'toplu komut yönetimi';
$lang['Caddie management'] = 'yardımcı yönetimi';
$lang['Caddie'] = 'yardımcı';
$lang['Albums authorized thanks to group associations'] = 'Albümler grup sayesinde yetkili';
$lang['Album manual order was saved'] = 'Albümlerin sıralaması kayıt edildi';
$lang['Check for upgrade failed for unknown reasons.'] = 'Güncelleme denetimi sonuçlanamıyor, Yaptığınız işlem basarısız oldu..';
$lang['Check for upgrade'] = 'Güncellemelere bak';
$lang['Comments for all'] = 'Hepsine yorum yap';
$lang['Current name'] = 'Geçerli isim';
$lang['Database'] = 'Veritabanı';
$lang['Deactivate'] = 'Devre dışı bırak';
$lang['Delete Representant'] = 'Temsilciyi Sil';
$lang['Delete selected tags'] = 'Seçilen etiketleri sil';
$lang['Delete selected users'] = 'Seçilen kullanıcılari sil';
$lang['Deletions'] = 'Silinenler';
$lang['Deny selected groups'] = 'seçilen grubu reddet';
$lang['Deny selected users'] = 'seçilen kullanıcılari reddet.';
$lang['Description'] = 'Tanım / açıklama';
$lang['Display options'] = 'Görüntü özellikleri';
$lang['Dissociated'] = 'Ayrismis';
$lang['Does not represent'] = 'Temsil edilmiyor / Karsiligi yok';
$lang['Edit selected tags'] = 'Seçilen etiketleri degiştir';
$lang['Edit tags'] = 'etiketleri degiştir';
$lang['Email admins when a new user registers'] = 'Yeni kullanıcı kaydı oldugunda yöneticiye e-posta gönder';
$lang['Email admins when a valid comment is entered'] = 'Yeni yorum eklendiginde yöneticiye e-posta gönder';
$lang['Email admins when a comment requires validation'] = 'Yorum onayı oldugunda yöneticiye e-posta gönder';
$lang['Environment'] = 'Ortam / Çevre';
$lang['Form'] = 'Biçim';
$lang['Gallery title'] = 'Galleri Başlığı';
$lang['Grant selected groups'] = 'Seçilen grupların kabulu';
$lang['Grant selected users'] = 'Seçilen kullanıcıların kabulu';
$lang['Group name'] = 'Grup Adı';
$lang['Groups'] = 'Gruplar';
$lang['Guests'] = 'Ziyaretçiler';
$lang['History'] = 'Geçmis';
$lang['Informations'] = 'Bilgiler';
$lang['Install'] = 'Kur';
$lang['Link all album photos to a new album'] = 'Bütün albüm resimlerini yeni albümü bağla';
$lang['Link all album photos to some existing albums'] = 'Bütün albüm resimlerini olan albümlere bağla';
$lang['Linked albums'] = 'bağlanan albümler';
$lang['Lock gallery'] = 'galeriyi kilitle';
$lang['Maintenance'] = 'Bakim';
$lang['Edit album permissions'] = 'albüm yetkilerini düzenle';
$lang['Manage permissions for group "%s"'] = 'Grup izinlerini düzenle"%s"';
$lang['Manage permissions for user "%s"'] = 'kullanıcı izinlerini düzenle "%s"';
$lang['Manage tags'] = 'Etiketleri düzenle';
$lang['Members'] = 'Üyeler';
$lang['Metadata synchronized from file'] = 'Metadata dosyadan senkronize edildi';
$lang['Move albums'] = 'albümleri taşı';
$lang['Move'] = 'Taşı';
$lang['Name'] = 'Isim';
$lang['New name'] = 'Yeni isim';
$lang['New parent album'] = 'yeni ana albüm';
$lang['New tag'] = 'Yeni etiket';
$lang['Number of comments per page'] = 'Her sayfadaki yorum sayisi';
$lang['Number of rates'] = 'Reyting sayisi';
$lang['Number of thumbnails to create'] = 'Yaratilacak thumbnail sayisi';
$lang['Only private albums are listed'] = 'sadecee özel albümler listelendi';
$lang['Operating system'] = 'Isletim sistemi';
$lang['Options'] = 'Seçenekler';
$lang['Other private albums'] = 'diğer özel albümler';
$lang['Page banner'] = 'Sayfa banneri';
$lang['Parent album'] = 'Ana albüm';
$lang['Path'] = 'Yol';
$lang['Permalink'] = 'Kalıcı Bağlantı';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Kalıcı Bağlantı %s albüm tarafından kullanıldı %s. Önce onu Kalıcı Bağlantı geçmişinden siliniz';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Kalıcı Bağlantı ismi a-z, A-Z, 0-9, "-", "_" yada "/" karekterlerinden olusmalidir. Sayisal olmamali veya sayi ile baslamamalidir';
$lang['Permalink %s is already used by album %s'] = 'Kalıcı Bağlantı %s albüm tarafından kullanıldı%s';
$lang['Permalink history'] = 'Kalıcı Bağlantı geçmisi';
$lang['Permalinks'] = 'Kalıcı Bağlantı';
$lang['Permission denied'] = 'İzin verilmedi';
$lang['Permission granted thanks to a group'] = 'Gruba tesekkür izni verildi';
$lang['Permission granted'] = 'İzin verildi';
$lang['Photo informations updated'] = 'Resim bilgileri güncellendi';
$lang['Caddie'] = 'Yardımcı';
$lang['Position'] = 'Pozisyon';
$lang['Preferences'] = 'Tercihler';
$lang['Properties'] = 'Özellikler';
$lang['Random photo'] = 'Karisik resim';
$lang['Rate date'] = 'Reyting tarihi';
$lang['Rating by guests'] = 'Misafir Puanları';
$lang['Rating'] = 'Puan';
$lang['Reject'] = 'Reddet';
$lang['Representant'] = 'Temsilen';
$lang['Representation of albums'] = 'Albüm gösterimi';
$lang['Representative'] = 'Temsilci';
$lang['Represents'] = 'Temsilciler';
$lang['Save order'] = 'Düzeni kaydet';
$lang['Save to permalink history'] = 'Kalıcı Bağlantı geçmisini kaydet';
$lang['Select at least one album'] = 'en az bir albüm seçiniz';
$lang['Select at least one photo'] = 'En az bir resim seçiniz';
$lang['Select at least one user'] = 'En az bir kullanıcı seçiniz';
$lang['Show info'] = 'Bilgi Göster';
$lang['Site manager'] = 'Site yöneticisi';
$lang['Status'] = 'Durum';
$lang['Statistics'] = 'Istatistikler';
$lang['Storage album'] = 'Depola albümü';
$lang['Sum of rates'] = 'Toplam reytingler';
$lang['Tag "%s" already exists'] = 'Etiket "%s" zaten var';
$lang['Tag "%s" was added'] = 'Etiket "%s" eklendi';
$lang['Tag selection'] = 'Etiket seçme';
$lang['The %d following tags were deleted'] = 'Asagidaki %d etiketler silindi';
$lang['Unable to check for upgrade.'] = 'Yükseltme kontrolü yapilamiyor.';
$lang['Uninstall'] = 'Kaldir';
$lang['Use the default photo sort order (defined in the configuration file)'] = 'Varsayilan görüntü siralama düzenini kullan';
$lang['User comments validation'] = 'kullanıcı yorumlari dogrulama';
$lang['Users'] = 'Kullanıcılar';
$lang['Validate'] = 'Onayla';
$lang['Validation'] = 'Onaylama';
$lang['Version'] = 'Versiyon';
$lang['Virtual albums to move'] = 'Taşınacak sanal albümler';
$lang['Virtual album name'] = 'Sanal albüm ismi';
$lang['Webmaster cannot be deleted'] = 'Site yöneticisi silinemez';
$lang['You are running on development sources, no check possible.'] = 'Gelistirme kaynaklarini kullaniyorsunuz incelemek mümkün degil';
$lang['You cannot delete your account'] = 'Kendi hesabinizi silemezsiniz';
$lang['You cannot move an album in its own sub album'] = 'Bir albümü kendi alt bölümü içindeki albüme taşıyamazsınız';
$lang['You need to confirm deletion'] = 'Silme islemini onaylayiniz';
$lang['add tags'] = 'Etiketler ekle';
$lang['Associate to album'] = 'bağla albüme';
$lang['associate to group'] = 'Gruba iliskilendirmek';
$lang['Authorized'] = 'Yetkili';
$lang['Add a virtual album'] = 'sanal albüm ekle';
$lang['Authorize users to add comments on selected albums'] = 'Kullanıcıları seçilen albümler için yorum yapmaya yetkilendir';
$lang['The name of an album must not be empty'] = 'Albüm ismi boş olamaz';
$lang['Lock albums'] = 'albümlerikilitle';
$lang['Private'] = 'Özel albüm';
$lang['Public'] = 'Genel albüm';
$lang['Find a new representant by random'] = 'Rasgele yeni bir temsilci bul';
$lang['Public / Private'] = 'Genel / Özel';
$lang['Manage authorizations for selected albums'] = 'Seçilen albümler için yetkileri yönetimi';
$lang['Virtual album added'] = 'sanal albüm eklendi';
$lang['Virtual album deleted'] = 'sanal albüm silindi';
$lang['Access type'] = 'Erisim türü';
$lang['Comments'] = 'Yorumlar';
$lang['Information data registered in database'] = 'Bilgilerin veritabaninda kayitli';
$lang['Default display'] = 'Varsayilan görüntü';
$lang['The gallery URL is not valid.'] = 'Galeri URL geçerli degil.';
$lang['Main'] = 'Ana';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Bir sayfadaki yorumlarin sayisini 5 ile 50 arasinda olmalidir.';
$lang['Configuration'] = 'Yapılandırma';
$lang['confirm'] = 'Onayla';
$lang['Date'] = 'Tarih';
$lang['delete album'] = 'albümüsil';
$lang['Dissociate from album'] = 'albümden ayır';
$lang['dissociate from group'] = 'Gruptan ayirmak';
$lang['edit album permissions'] = 'albüm yetkilerini düzenle';
$lang['Album updated successfully'] = 'Albüm bilgileri güncellendi.';
$lang['photos per page'] = 'Safya basina içerikler';
$lang['High definition enabled'] = 'Yüksek çözünürlüklü etkin';
$lang['File'] = 'Dosya';
$lang['Filesize'] = 'Dosya boyutu';
$lang['first photo added on %s'] = 'Ilk içerigin eklenme zamani %s';
$lang['Forbidden'] = 'Yasaklanmis';
$lang['global mode'] = 'Küresel mod';
$lang['group "%s" added'] = 'Grup "%s" eklendi';
$lang['group "%s" deleted'] = 'Grup "%s" silindi';
$lang['group "%s" updated'] = 'Grup "%s" güncellendi';
$lang['group'] = 'Grup';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Bir grubun ismi " veya \ içermemelidir yada bos olmamalidir.';
$lang['This name is already used by another group.'] = 'Bu isim baska bir grup tarafindan kullanilmaktadir';
$lang['High definition'] = 'Yüksek çözünürlüklü';
$lang['jump to album'] = 'albüme geç';
$lang['jump to photo'] = 'Resime geç';
$lang['leave'] = 'Ayril';
$lang['Lock'] = 'Kilit';
$lang['Locked'] = 'Kilitlendi';
$lang['manage album photos'] = 'albüm resimlerini yönet';
$lang['manage sub-albums'] = 'yönet alt-albümler';
$lang['Manage'] = 'Yönet';
$lang['maximum height'] = 'Maksimum yükseklik';
$lang['maximum width'] = 'Maksimum genislik';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Yürütme zaman asimi, islem devam etmeli [Tahmini zaman: %d saniye].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Yürütme zaman asimi, islem devam etmeli [Tahmini zaman: %d saniye].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Zamanli posta gönderilecek kullanıcılar listesi. Diger kullanıcılar listelenmez.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Posta gönderme zamani sinirlidir.Diger postalar atlandi.';
$lang['To send ?'] = 'Göndermek için?';
$lang['Last send'] = 'Son gönderilen';
$lang['email'] = 'E-Posta';
$lang['User'] = 'kullanıcı';
$lang['Complementary mail content'] = 'Tamamlayici posta içerigini';
$lang['See you soon,'] = 'Yakinda görüsürüz,';
$lang['Go to'] = 'Git';
$lang['Hello'] = 'Merhaba';
$lang['New photos were added'] = 'Yeni içerikler eklendi';
$lang['on'] = 'üzerinde';
$lang['between'] = 'arasinda';
$lang['and'] = 've';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Site yöneticisi posta ile haberdar olmaniz için sizi abone etti.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Posta yoluyla bildirimleri almak için abone oldunuz.';
$lang['To subscribe'] = 'Abone olmak için';
$lang['If you encounter problems or have any question, please send a message to'] = 'Eger sorun yasarsaniz ya da herhangi bir soruniz var ise, bir mesaj gönderiniz';
$lang['[NBM] Problems or questions'] = 'Sorunlar veya sorular';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Site yöneticisi posta ile haberdar edilme aboneliginizi kaldirdi.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Posta yoluyla bildirimleri almak için olan aboneliginizi iptal ettiniz.';
$lang[', click on'] = ', tiklayiniz';
$lang['To unsubscribe'] = 'Abonelikten çikarmak için';
$lang['With blank value, gallery title will be used'] = 'Bos olursa, galeri baslik kullanilir';
$lang['Notification'] = 'Duyuru';
$lang['Error when sending email to %s [%s].'] = 'E-Posta gönderirken hata %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Posta gönderildi %s [%s].';
$lang['%d mail was sent.'] = '%d posta gönderildi.';
$lang['%d mails were sent.'] = '%d postalar gönderildi.';
$lang['%d mail was not sent.'] = '%d posta gönderilemedi.';
$lang['%d mails were not sent.'] = '%d postalar gönderilemedi.';
$lang['No mail to send.'] = 'Gönderilecek posta yok';
$lang['There is no available subscribers to mail.'] = 'Hiç posta abonesi yok.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Aboneler sadece yeni içerikler';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Bu sekmeyi sadece site yöneticisi görebilir diger yöneticiler degil göremez. ';
$lang['No user to send notifications by mail.'] = 'Posta ile ildiri gördermek için hiç kullanıcı yok';
$lang['New photos added'] = 'Yeni içerik eklendi';
$lang['Subscribe to notification by mail'] = 'Posta ile abone bildirimi';
$lang['Unsubscribe from notification by mail'] = 'Bildiri aboneliginden çik';
$lang['Parameter'] = 'Ayarlar';
$lang['Operation in progress'] = 'Islem yapiliyor.';
$lang['Please wait...'] = 'Lütfen bekleyiniz...';
$lang['Continue processing treatment'] = 'Isleme devam ediniz';
$lang['Add detailed content'] = 'Bazi detayli içerik ekleyin';
$lang['Send mail as'] = 'Posta gönderim sekli';
$lang['Send mail to users'] = 'kullanıcılara posta gönderin';
$lang['Send'] = 'Gönder';
$lang['Subscribed'] = 'Abone olundu';
$lang['Subscribe'] = 'Abone';
$lang['Parameters'] = 'Parametreler';
$lang['Select recipients'] = 'Alicilari seç';
$lang['Subscribe/unsubscribe users'] = 'kullanıcılar Abone/Abone degil';
$lang['Unsubscribed'] = 'Abonelikten çikarildi';
$lang['%d parameter was updated.'] = '%d parametre güncellendi.';
$lang['%d parameters were updated.'] = '%d parametreler güncellendi.';
$lang['%d user was not updated.'] = '%d kullanıcı güncellenemedi.';
$lang['%d users were not updated.'] = '%d kullanıcılar güncellenemedi.';
$lang['User %s [%s] was removed from the subscription list.'] = 'kullanıcı %s [%s] abone listesinden silindi.';
$lang['User %s [%s] was added to the subscription list.'] = 'kullanıcı %s [%s] abone listesine eklendi.';
$lang['%d user was updated.'] = '%d kullanıcı güncellendi.';
$lang['%d users were updated.'] = '%d kullanıcılar güncellendi.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'kullanıcı %s [%s] abone listesinden silinemedi..';
$lang['User %s [%s] was not added to the subscription list.'] = 'kullanıcı %s [%s] abone listesine eklenemedi.';
$lang['User %s [%s] added.'] = 'kullanıcı %s [%s] eklendi.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Uyari abone olurken veya çikarken kullanıcılara mail gönderecegiz.';
$lang['Send mail on HTML format'] = 'Postayi HTML formatinda yolla';
$lang['Include display of recent photos grouped by dates'] = 'Son resimleri tarihlerine göre gruplandirilmis görüntülenecek';
$lang['Available only with HTML format'] = 'Sadece HTML formatinda kullanilabilir';
$lang['no write access'] = 'Yazma yetkisi yok';
$lang['Permissions'] = 'Izinler';
$lang['private'] = 'Özel';
$lang['public'] = 'Genel';
$lang['Purge never used notification feeds'] = 'Kullanilmamis beslemeleri temizle';
$lang['Purge sessions'] = 'Temizleme oturumlari';
$lang['randomly represented'] = 'Karisik temsici';
$lang['registration date'] = 'Kayit tarihi';
$lang['clean'] = 'Temizle';
$lang['remove remote listing.xml file'] = 'uzak listing.xml dosyasini sil';
$lang['generate listing'] = 'Liste olustur';
$lang['generate file listing.xml on remote site'] = 'uzak sitede listing.xml dosyasini olustur';
$lang['Create this site'] = 'Siteyi olustur';
$lang['A local listing.xml file has been found for'] = 'Yerel listing.xml dosya bulundu';
$lang['read local listing.xml and update'] = 'yerel listing.xml dosyasini oku ve güncelle';
$lang['test'] = 'deneme';
$lang['test this remote site'] = 'uzak siteyi dene';
$lang['remove tags'] = 'etiketleri sil';
$lang['Repair and optimize database'] = 'Veritabanini onar ve en uygun hale getir';
$lang['selection'] = 'Seçim';
$lang['set to'] = 'Ayarla';
$lang['singly represented'] = 'tek basina temsil';
$lang['This site already exists'] = 'Bu site zaten var';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Yeni bir siteyarat: () URL\'sine create_listing_file.php adi ver';
$lang['created'] = 'yaratildi';
$lang['delete'] = 'sil';
$lang['delete this site and all its attached elements'] = 'bu siteyi ve eklenen tüm içerigi sil';
$lang['deleted'] = 'silindi';
$lang['an error happened'] = 'Bir hata olustu';
$lang['file create_listing_file.php on remote site was not found'] = 'create_listing_file.php dosya uzak sitede bulunamadi';
$lang['Local'] = 'Yerel';
$lang['Remote'] = 'Uzak';
$lang['synchronize'] = 'Senkronize etmek';
$lang['update the database from files'] = 'Dosyalar ile veritabani güncelleme';
$lang['status'] = 'Durum';
$lang['Directory'] = 'Dizin';
$lang['sub-albums'] = 'alt-albümler';
$lang['synchronize metadata'] = 'Senkronize metadata';
$lang['target'] = 'Hedef';
$lang['Thumbnail'] = 'Küçük resim';
$lang['title'] = 'Baslik';
$lang['Album list management'] = 'Albümler yönetimi';
$lang['Piwigo configuration'] = 'Piwigo yapılandırma';
$lang['Edit album'] = 'Albüm düzenle';
$lang['Group management'] = 'Grup yönetimi';
$lang['User list'] = 'Kullanıcılar listesi';
$lang['Edit photo information'] = 'Resim bilgilerini düzenle';
$lang['Thumbnail creation'] = 'Küçük resim oluştur';
$lang['Database synchronization with files'] = 'Dosya ile veritabani senkronize';
$lang['all'] = 'tüm';
$lang['photos without thumbnail (jpeg and png only)'] = 'Küçük resim olmayan resimler (jpeg ve sadece png)';
$lang['height must be a number superior to'] = 'yüksekligi bir sayi olmali';
$lang['width must be a number superior to'] = 'genisligi bir sayi olmali';
$lang['for the file format'] = 'dosya biçimi için';
$lang['No missing thumbnail'] = 'Eksik Küçük resim';
$lang['Photo unreachable or no support'] = 'Resim erisilemiyor veya desteklenmeyen format';
$lang['GD version'] = 'GD sürümü';
$lang['Miniaturization parameters'] = 'Minyatürlestirme parametreleri';
$lang['generated in'] = 'olusturuldu';
$lang['Results of miniaturization'] = 'Minyatürlestirme süreci sonuçlari';
$lang['General statistics'] = 'Genel istatistik';
$lang['max time'] = 'en uzun süre';
$lang['average time'] = 'ortalama süre';
$lang['min time'] = 'men kisa time';
$lang['number of miniaturized photos'] = 'oluşturulan küçük resim sayısı';
$lang['total time'] = 'toplam zaman';
$lang['for this file format'] = 'Bu dosya biçimi için';
$lang['unit mode'] = 'tek modlu';
$lang['Unlocked'] = 'Kilitsiz';
$lang['unset'] = 'Kaldırmak';
$lang['Month'] = 'Sıra';
$lang['Update albums informations'] = 'Albümlerin bilgilerini güncelle';
$lang['Update photos information'] = 'Resimlerin bilgilerini güncelle';
$lang['Synchronize'] = 'Senkronize';
$lang['reduce to single existing albums'] = 'mevcut albümleri küçült';
$lang['Choose an option'] = 'Bir seçenek seç';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'En fazla bilgileri göster (eklenen albümler resimler, silinen albümler resimler)';
$lang['Piwigo version differs on the remote site'] = 'Piwigo sürümü uzak sitede farklı';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Uzak site ve Piwigo üzerinde create_listing_file.php sürümleri aynı olmalıdır';
$lang['listing.xml file was not found'] = 'listing.xml dosyası bulunamadı';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'listing.xml dosya uzak sitede bulunamadı. Bu dosya Site yöneticisi "liste oluşturmak" komutu ile oluşturulur';
$lang['Error list'] = 'Hataların Listesi';
$lang['Errors caption'] = 'Hataların başlıkları';
$lang['Detailed informations'] = 'Detaylı bilgi';
$lang['File/directory read error'] = 'Dosya / dizin okuma hatası';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Dosya veya dizin erişemez (ya yok yada erişim reddedildi)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Bir resim thumbnail (küçük resim) gerektirir. Thumbnail alt dizinde mevcut kategori dizinin "thumbnail" listesinde olmalıdır.Thumbnail yapılandırılmış thumbnail öneki ve uzantısı ile aşağıdaki listede arasında olmalıdır :';
$lang['missing thumbnail'] = 'thumbnail eksik';
$lang['albums deleted in the database'] = 'veri tabanından silinen albümler';
$lang['photos deleted from the database'] = 'elemanlar veritabanında silindi';
$lang['photos candidates for metadata synchronization'] = 'metadata senkronizasyon için görüntüleri adayları';
$lang['photos informations synchronized with files metadata'] = 'elemanları bilgiler dosyaları ile metadata senkronize edildi';
$lang['errors during synchronization'] = 'Senkronizasyon sırasında hatalar';
$lang['albums added in the database'] = 'veri tabanına eklenen albümler';
$lang['photos added in the database'] = 'elemanlar veritabanında ekledi';
$lang['photos updated in the database'] = 'elemanlar veritabanında güncellendi';
$lang['Search for new images in the directories'] = 'Dizinlerde yeni resimler ara';
$lang['added'] = 'eklendi';
$lang['Metadata synchronization results'] = 'Metadata senkronizasyon sonuçları';
$lang['only perform a simulation (no change in database will be made)'] = 'sadece veritabanında değişecektir) bir simülasyon (hiçbir şey yapılmayacak)';
$lang['[Simulation]'] = '[Simülasyon]';
$lang['Simulation'] = 'Simülasyon';
$lang['directories + files'] = 'dizinler + resimler';
$lang['only directories'] = 'sadece dizinler';
$lang['synchronize files structure with database'] = 'veritabanı ile dosya yapısı senkronize et';
$lang['synchronize files metadata with database photos informations'] = 'meta dosyaları ile veritabanı elemanları senkronize';
$lang['even already synchronized photos'] = 'hatta elemanlar senkronize edildi';
$lang['Used metadata'] = 'Metadata kullanıldı';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Dizin ve dosya ismi sadece harfler, rakamlardan olmalı, "-", "_" veya "."';
$lang['wrong filename'] = 'yanlış dosya';
$lang['Upload'] = 'Yükle';
$lang['user "%s" added'] = 'Kullanıcı "%s" eklendi';
$lang['User status'] = 'Kullanıcı durumu';
$lang['user_status_admin'] = 'Yönetici';
$lang['user_status_generic'] = 'Genel';
$lang['user_status_guest'] = 'Misafir';
$lang['user_status_normal'] = 'Kullanıcı';
$lang['user_status_webmaster'] = 'Site Yöneticisi';
$lang['Virtual album'] = 'Sanal albüm';
$lang['Waiting'] = 'Bekleyen';
$lang['default'] = 'Varsayılan';
$lang['Toggle \'default group\' property'] = 'Ters \'varsayılan\' özellik';
$lang['Advanced features'] = 'Gelişmiş özellikler';
$lang['Specials'] = 'Özel Ürünler';
$lang['Overall'] = 'Genel bakış';
$lang['Year'] = 'Yıl';
$lang['Day'] = 'Gün';
$lang['Pages seen'] = 'Görülen Sayfalar';
$lang['Time'] = 'Zaman';
$lang['IP'] = 'İp';
$lang['Element'] = 'Eleman';
$lang['Section'] = 'Bölüm';
$lang['Tags'] = 'Etiketler';
$lang['Save page visits by guests'] = 'Misafir tarafından ziyaret edilen sayfaları kayıt et';
$lang['Save page visits by users'] = 'Kullanıcılar tarafından ziyaret edilen sayfaları kayıt et';
$lang['Save page visits by administrators'] = 'Yöneticiler tarafından ziyaret edilen sayfaları kayıt et';
$lang['An information email was sent to group "%s"'] = 'Bilgi e-postası "%s" grubuna gönderildi';
$lang['Send an information email to group members'] = 'Grup üyelerine bilgi e-postası gönder';
$lang['Group'] = 'Grup';
$lang['[%s] Visit album %s'] = '[%s] albümü gez%s';
$lang['Hello,'] = 'Merhaba,';
$lang['See you soon.'] = 'Sonra görüşürüz.';
$lang['Discover album:'] = 'Albümü tanı:';
$lang['Mail content'] = 'Posta içeriği';
$lang['none'] = 'Hiç';
$lang['high'] = 'Yüksek';
$lang['other'] = 'Diğer';
$lang['Element type'] = 'Eleman türü';
$lang['Image id'] = 'Resim id';
$lang['Summary'] = 'Özet';
$lang['%d line filtered'] = '%d satır filtre edildi';
$lang['%d lines filtered'] = '%d satırlar filtre edildi';
$lang['%d guest'] = '%d Misafir';
$lang['%d guests'] = '%d Misafirler';
$lang['Hour'] = 'Saat';
$lang['guest'] = 'Misafir';
$lang['default values'] = 'varsayılan değerler';
$lang['High filesize'] = 'Yüksek çözünürlüklü dosya boyutu';
$lang['Guest cannot be deleted'] = 'Misafir silinemez';
$lang['Default user cannot be deleted'] = 'Varsayılan kullanıcı silinemez';
$lang['Purge history detail'] = 'Tarih detaylarını temizle';
$lang['Purge history summary'] = 'Tarih özetini temizle';
$lang['Check integrity'] = 'Bütünlüğünü kontrol';
$lang['Anomaly'] = 'Aykırılık';
$lang['Correction'] = 'Düzeltme';
$lang['Automatic correction'] = 'Otomatik düzeltme';
$lang['Impossible automatic correction'] = 'Otomatik düzeltme imkansız';
$lang['Correction applied with success'] = 'Düzeltme başarıyla uygulandı';
$lang['Correction applied with error'] = 'Düzeltme hata ile uygulandı';
$lang['%d anomaly has been detected.'] = '%d anormallik tespit edildi.';
$lang['%d anomalies have been detected.'] = '%d anormallikler tespit edildi.';
$lang['%d anomaly has been corrected.'] = '%d anormallik düzeltildi.';
$lang['%d anomalies have been detected corrected.'] = '%d anormallikler tespit edildi ve düzeltildi.';
$lang['%d anomaly has not been corrected.'] = '%d anormallik düzeltilemedi.';
$lang['%d anomalies have not been corrected.'] = '%d anormallikler düzeltilemedi.';
$lang['Go to %s or %s for more informations'] = 'Daha fazla bilgi için %s veya %s';
$lang['the forum'] = 'Forum';
$lang['the wiki'] = 'Wiki';
$lang['%s value is not correct file because exif are not supported'] = '%s exif desteklenmez çünkü değeri yanlış';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s false olarak ayarlanmalı /config/config.inc.php dosyası içinde';
$lang['Main "guest" user does not exist'] = 'Ana "Misafir" kullanıcı yok';
$lang['Main "guest" user status is incorrect'] = 'Ana "Misafir" kullanıcı durumu yanlış';
$lang['Default user does not exist'] = 'Varsayılan kullanıcı yok';
$lang['Main "webmaster" user does not exist'] = 'Ana "Site Yöneticisi" kullanıcı yok';
$lang['Main "webmaster" user status is incorrect'] = 'Ana "Site Yöneticisi" kullanıcı durumu yanlış';
$lang['User "%s" created with "%s" like password'] = 'Kullanıcı "%s" şifre "%s" ile yaratıldı';
$lang['Status of user "%s" updated'] = 'Kullanıcı "%s" durumu güncellendi';
$lang['add new photos to caddie'] = 'Yardımcıya yeni elemanlar ekle';
$lang['No display'] = 'Görüntü yok';
$lang['Classic display'] = 'Klasik ekran';
$lang['Hoverbox display'] = 'Hoverbox ekran';
$lang['Mail address is obligatory for all users'] = 'Posta adresi tüm kullanıcılar için zorunludur';
$lang['Minimum privacy level'] = 'En az gizlilik seviyesi';
$lang['Privacy level'] = 'Gizlilik seviyesi';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Tanıdıklar';
$lang['Level 2'] = 'Arkadaşlar';
$lang['Level 4'] = 'Aile';
$lang['Level 8'] = 'Yöneticiler';
$lang['Reinitialize check integrity'] = 'Bütünlüğünü kontrolü yeniden başlat';
$lang['Check all'] = 'Hepsini işaretle';
$lang['Uncheck all'] = 'Tüm işaretleri kaldır';
$lang['Check automatic corrections'] = 'Otomatik düzeltme kontrol et';
$lang['Apply selected corrections'] = 'Seçilen düzeltmeleri uygula';
$lang['Ignore selected anomalies'] = 'Seçilen anormallikleri yoksay';
$lang['Refresh'] = 'Yenile';
$lang['The anomaly will be ignored until next application version'] = 'Bu anormallik sonraki uygulama sürümüne kadar dikkate alınmayacaktır';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Düzeltilmiş anormallik artık yok sayılır';
$lang['%d anomaly has been ignored.'] = '%d anormallik yok sayıldı.';
$lang['%d anomalies have been ignored.'] = '%d anormallikler yok sayıldı.';
$lang['Plugins which need upgrade'] = 'Yükseltilecek eklentiler';
$lang['Plugin list'] = 'Eklenti listesi';
$lang['Check for updates'] = 'Güncellemeyi dene';
$lang['Other plugins'] = 'Diğer eklentiler';
$lang['Last revisions'] = 'Son revizyonlar';
$lang['Delete'] = 'Sil';
$lang['Are you sure you want to delete this plugin?'] = 'Bu eklentiyi sileceğinizden emin misiniz?';
$lang['Are you sure you want to install this plugin?'] = 'Bu eklentiyi kuracağınızdan emin misiniz?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Bu yükseltmeyi yüklemek istediğinizden emin misiniz?Bu sürüm öncesinde kaldırma ihtiyacı olmadığını doğrulamalısınız';
$lang['%s has been successfully upgraded.'] = '%s başarıyla yükseltilmiştir.';
$lang['Plugin has been successfully copied'] = 'Eklenti başarıyla kopyalanmış oldu';
$lang['You might go to plugin list to install and activate it.'] = 'Yükleme ve aktif etmek için eklentiler listesine gidiniz';
$lang['Can\'t create temporary file.'] = 'Geçici dosya oluşturulamadı.';
$lang['Can\'t download archive.'] = 'Arşiv yüklenemedi.';
$lang['Can\'t read or extract archive.'] = 'Arşiv okunamadı veya ayıklanamadı.';
$lang['An error occured during extraction (%s).'] = '(%s) dosyaları ayıklanırken hata oluştu.';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Lütfen "plugins" klasörünü ve alt klasörler izinleri (CHMOD) kontrol edin.';
$lang['Can\'t connect to server.'] = 'Sunucuya bağlantı imkansız.';
$lang['Purge compiled templates'] = 'Derlenmiş şablonları temizle';
$lang['ACCESS_0'] = 'Ücretsiz erişim';
$lang['ACCESS_1'] = 'Herkese erişim';
$lang['ACCESS_2'] = 'Kayıtlı kullanıcılara erişim';
$lang['ACCESS_3'] = 'Adminlere erişim';
$lang['ACCESS_4'] = 'Site töneticilerine erişim';
$lang['ACCESS_5'] = 'Erişim yok';
$lang['Support'] = 'Destek';
$lang['Documentation'] = 'Belgeler';
$lang['A new version of Piwigo is available.'] = 'Piwigo yeni bir sürümü mevcut.';
$lang['Piwigo Administration'] = 'Piwigo Yönetim';
$lang['Piwigo version'] = 'Piwigo versiyon';
$lang['You are running the latest version of Piwigo.'] = 'Piwigo son sürümünü çalıştırıyorsunuz.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Bu %s versiyonu yüklenen [%s] versiyonu ile uyumlu değildir.';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Sisteminizi yükseltmelisiniz aksi taktirde uygulama yanlış veya hiç çalışmayabilir.';
$lang['Deleted on'] = 'Silindi';
$lang['Last hit'] = 'En son ziyaret';
$lang['GD library is missing'] = 'GD arşivi eksik';
$lang['Templates'] = 'Şablonlar';
$lang['Extend for templates'] = 'Şablonları genişlet';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Orjinal şablon temsilcisi özelleştirilmiş şablonlar template-extension yedek dosyasından';
$lang['Replacers (customized templates)'] = 'Yedekler (Özelleştirilmiş şablonlar)';
$lang['Original templates'] = 'Orjinal Şablonlar';
$lang['Optional URL keyword'] = 'İsteğe bağlı URL anahtar kelime';
$lang['Templates configuration has been recorded.'] = 'Şablonları yapılandırma kaydedildi.';
$lang['All optimizations have been successfully completed.'] = 'Tüm optimizasyonları başarıyla tamamlanmıştır.';
$lang['Optimizations have been completed with some errors.'] = 'ptimizasyonları bazı hatalar ile tamamlanmıştır.';
$lang['Modify information'] = 'Bilgi değiştirme';
$lang['edit album'] = 'albüm bilgisini düzenle';
$lang['nothing'] = 'hiçbir şey';
$lang['overrides existing values with empty ones'] = 'boş olan değerleri geçersiz kılar';
$lang['manage photo ranks'] = 'resim rütbesini yönet';
$lang['Manage photo ranks'] = 'Resim rütbesini yönet';
$lang['Edit ranks'] = 'Rütbeleri yönet';
$lang['No photo in this album'] = 'albümde eleman yok';
$lang['Images manual order was saved'] = 'Resimlerin elle sırlandırılması kayıt edildi';
$lang['ranks'] = 'rütbeler';
$lang['By rank'] = 'Rütbece';
$lang['Manual order'] = 'Eller yapılandırma';
$lang['Drag to re-order'] = 'Tıkla ve sürükle yeniden yapılandır';
$lang['Quick Local Synchronization'] = 'Hızlı Yerel Senkronizasyon';
$lang['No photo can be deleted'] = 'Silinebilecek resim yok';
$lang['Delete selected photos'] = 'Seçili resimleri sil';
$lang['%d photo was deleted'] = '%d resim silindi';
$lang['%d photos were deleted'] = '%d resimler silindi';
$lang['Downloads'] = 'İndirilecekler';
$lang['Released on'] = 'Eklenme zamanı';
$lang['Number of downloads'] = 'İndirilen sayısı';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Duyuru Bülteni';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Piwigo proje ile temas halinde olun.Piwigo Duyuru Haber Bülteni\'ne abone olun.Ne zaman yeni bir sürüm (bazen bir güvenlik veya hata çözümü dahil) ve önemli olaylar, projeye ne olduğunu anlatan e-postalar alacaksınız, önemli olan bilmek ve yükseltmek.Sadece yılda bir kaç e-posta.';
$lang['Subscribe %s'] = 'Abone %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Abone %s Piwigo Bülten Duyurularına';
$lang['Purge search history'] = 'Arama geçmişini temizle';
$lang['Hide'] = 'Gizle';
$lang['Password is missing. Please enter the password.'] = 'Şifre eksik. Lütfen şifrenizi girin.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Şifre doğrulama eksik. Lütfen seçtiğiniz şifreyi onaylayın.';
$lang['Password confirmation error.'] = 'Şifre doğrulama hatası.';
$lang['Allow users to edit their own comments'] = 'Kullanıcıların kendi yorumlarını düzenlemesine izin ver';
$lang['Allow users to delete their own comments'] = 'Kullanıcıların kendi yorumlarını silmesine izin ver';
$lang['Email administrators when a comment is modified'] = 'Yöneticilere yorum düzenlendiği zaman e-posta yolla.';
$lang['Email administrators when a comment is deleted'] = 'Yöneticilere yorum silindiği zaman e-posta yolla.';
$lang['Cannot delete the old permalink !'] = 'Eski Kalıcı Bağlantı silinemez!';
$lang['Hit'] = 'Tıklanma';
$lang['Tools'] = 'Araçlar';
$lang['Photos'] = 'Resimler';
$lang['Themes'] = 'Temalar';
$lang['Instructions to use Piwigo'] = 'Piwigo kullanma talimatları';
$lang['Installed Themes'] = 'Yüklenen temalar';
$lang['Add New Theme'] = 'Yeni bir tema ekle';
$lang['Forbid this theme to users'] = 'Bu temayı kullanıcılara yasakla';
$lang['Set as default theme for unregistered and new users'] = 'Kayıtsız ve yeni kullanıcılar için varsayılan tema olarak ayarla';
$lang['unknown'] = 'bilinmeyen';
$lang['Upload Photos'] = 'Resim Yükle';
$lang['Drop into album'] = 'albüm içine bırak';
$lang['+ Add an upload box'] = '+ Bir yükleme kutusu ekleyin';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Bir "%s" dizini açınız Piwigo kurduğunuz yerde.';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Yetki veriniz (chmod 777) "%s" dizinine chmod 777 yapınız Piwigo kurduğunuz yerde';
$lang['existing album'] = 'olan albüm';
$lang['create a new album'] = 'albüm albüm aç';
$lang['Album name'] = 'Albüm ismi';
$lang['Album "%s" has been added'] = 'kategori "%s" eklendi';
$lang['Uploaded Photos'] = 'Yüklenen resimler';
$lang['%d photos uploaded'] = '%d resimler yüklendi';
$lang['Privacy level set to "%s"'] = 'Gizlilik seviyesi "%s" için';
$lang['Album "%s" now contains %d photos'] = 'kategori "%s" şimdi %d resimlerini içeriyor';
$lang['Manage this set of %d photos'] = 'Düzenle bu dizi %d resimleri';
$lang['Select files'] = 'Dosyaları seçin';
$lang['Everybody'] = 'Herkes';
$lang['Who can see these photos?'] = 'Kim bu resimleri görebilir?';
$lang['Who can see this photo?'] = 'Kim bu resimi görebilir?';
$lang['The websize maximum width must be a number between %d and %d'] = 'En fazla genişlik %d ve %d sayıları arasında olmalı';
$lang['The websize maximum height must be a number between %d and %d'] = 'En fazla yükseklik %d be %d sayıları arasında olmalı';
$lang['The websize image quality must be a number between %d and %d'] = 'Resim kalitesi  %d ve %d sayıları arasında olmalı';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'En fazla küçük resim genişliği %d ve %d sayıları arasında olmalı';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'En fazla küçük resim yüksekliği %d ve %d sayıları arasında olmalı';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Küçük resim kalitesi %d ve %d sayıları arasında olmalı';
$lang['Settings'] = 'Ayarlar';
$lang['Web size photo'] = 'Site resim boyutu';
$lang['Resize'] = 'Tekrar boyutlandır';
$lang['Maximum Width'] = 'En fazla genişlik';
$lang['pixels'] = 'pikseller';
$lang['Maximum Height'] = 'En fazla yükseklik';
$lang['Image Quality'] = 'Resim kalitesi';
$lang['Save Settings'] = 'Ayarları kaydet';
$lang['Your configuration settings are saved'] = 'Yapılandırma ayarları kaydedildi';
$lang['Active Themes'] = 'Aktif temalar';
$lang['Add write access to the "%s" directory'] = 'Yazma erişimi ekle "%s" dizinine';
$lang['Administration Home'] = 'Yönetim Ana sayfa';
$lang['Change Admin Colors'] = 'Yönetim sayfa renk değişimi';
$lang['Delete this theme'] = 'Bu temayı sil';
$lang['Directory does not exist'] = 'Dizin yok';
$lang['Download,'] = 'indir,';
$lang['FTP + Synchronization'] = 'FTP + Senkronizasyon';
$lang['Get Support on Piwigo Forum'] = 'Piwigo forum destek alın';
$lang['Help Me'] = 'Bana yardım edin';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Ana tema eksik olduğundan bu tema, aktif olamazdı: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Bu tema, silinemez çünkü diğer temalar buna bağlı %s';
$lang['Inactive Themes'] = 'Aktif olmayan temalar';
$lang['Install on your computer,'] = 'Bilgisayarınızda yükleyin,';
$lang['Make this theme available to users'] = 'Bu temayı kullanıcılara açık yapın';
$lang['Page end'] = 'Sayfa sonu';
$lang['Piwigo Uploader'] = 'Piwigo Yükleyici';
$lang['Read Piwigo Documentation'] = 'Piwigo Belgeleri Oku';
$lang['Start pLoader and add your photos.'] = 'pLoader başlat ve resimler yükle.';
$lang['Switch to clear or dark colors for administration'] = 'Açık veya koyu renk yönetim sayfasına geç';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'İmkansız bu dili devre dışı bırakmak için, en az bir dil gerekir.';
$lang['Inactive Languages'] = 'Aktif olmayan diller';
$lang['Make this language available to users'] = 'Bu dil kullanıcılara açık olsun';
$lang['Set as default language for unregistered and new users'] = 'Kayıtsız ve yeni kullanıcılar için varsayılan dil olarak ayarlamak';
$lang['Add Photos'] = 'Resim ekle';
$lang['Download'] = 'İndir';
$lang['The following tag was deleted'] = 'Aşağıdaki etiketi silindi';
$lang['Miscellaneous'] = 'Karışık';
$lang['Virtual Links'] = 'Sanal Linkler';
$lang['There is no other language available.'] = 'Kullanılabilir başka bir dil yok.';
$lang['There is no other plugin available.'] = 'Kullanılabilir başka bir eklenti yok.';
$lang['There is no other theme available.'] = 'Kullanılabilir başka bir teama yok';
$lang['Add another set of photos'] = 'Başka bir resim seti ekleyin';
$lang['Order of menubar items has been updated successfully.'] = 'Menü öğeleri sıralaması başarıyla güncellendi.';
$lang['This theme was not designed to be directly activated'] = 'Bu tema doğrudan harekete geçmek için tasarlanmış değildir';
$lang['Pending Comments'] = 'Bekleyen Yorumlar';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'php.ini dosyasındaki upload_max_filesize (%sB),  post_max_size (%sB) den daha büyük bu ayarı değiştirmelisin.';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif eklentisi hazır değil, yönetici exif hizmet dışı bırakmalı';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Yüklenen dosyanın php.ini upload_max_filesize aşıyor: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Yüklenen dosyalar php.ini post_max_size aşıyor: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Yüklenen dosya HTML biçiminde belirtilmiş MAX_FILE_SIZE aşıyor';
$lang['The uploaded file was only partially uploaded'] = 'Yüklenen dosya sadece kısmen yüklendi';
$lang['No file was uploaded'] = 'dosya yüklenmedi';
$lang['Missing a temporary folder'] = 'Geçici bir klasöre eksik';
$lang['Failed to write file to disk'] = 'Dosya diske yazılamadı';
$lang['File upload stopped by extension'] = 'Dosya yükleme Ek tarafından durduruldu';
$lang['Unknown upload error'] = 'Bilinmeyen yükleme hata';
$lang['Error on file "%s" : %s'] = 'Hata dosyada "%s" : %s';
$lang['Theme has been successfully installed'] = 'Tema başarıyla yüklendi';
$lang['Visit Gallery'] = 'Galeriyi ziyaret et';
$lang['Visit Piwigo project website'] = 'Piwigo proje sitesini ziyaret et';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader <em>Piwigo Yükleyiciyi temsil eder</em>. Bilgisayarınızdan, pLoader fotoğraflarınızı hazırlar ve Piwigo fotoğraf galerisi aktarabilirsiniz.';
$lang['Guest Settings'] = 'Misafir ayarları';
$lang['Main Page'] = 'Ana Sayfa';
$lang['Photo Page'] = 'Resim Sayfası';
$lang['Activate Navigation Bar'] = 'Gezinti çubuğunu aktiflestir';
$lang['Activate Navigation Thumbnails'] = 'Küçük resimler gezinti çubuğunu aktiflestir';
$lang['Activate icon "%s"'] = 'Aktifleştir simge "%s"';
$lang['Activate field "%s"'] = 'Aktifleştir alan "%s"';
$lang['Photo Properties'] = 'Resim özellikleri';
$lang['Allow user customization'] = 'Kullanıcı özelleştirme izin ver';
$lang['Languages'] = 'Diller';
$lang['Installed Languages'] = 'Yüklü Diller';
$lang['Add New Language'] = 'Yeni bir dil ekle';
$lang['Language has been successfully installed'] = 'Dil başarıyla yüklendi';
$lang['Select:'] = 'Seç:';
$lang['None'] = 'Hiçbiri';
$lang['Invert'] = 'Ters çevir';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Bu tema devreden çıkarmak imkansız, en az bir tema gerekir.';
$lang['Webmaster status is required.'] = 'Site yöneticisi durum gereklidir.';
$lang['Bound Theme'] = 'Yükümlü tema';
$lang['Allow rating'] = 'Puanlamaya izin ver';
$lang['Select at least one comment'] = 'En az bir yorum seç';
$lang['Active Plugins'] = 'Aktif Eklentiler';
$lang['Inactive Plugins'] = 'Aktif olmayan Eklentiler';
$lang['Missing Plugins'] = 'Eksik Eklentiler';
$lang['Uninstalled Plugins'] = 'Kaldırılan eklentiler';
$lang['By %s'] = 'Tarafından %s';
$lang['Visit plugin site'] = 'Ziyaret eklenti sitesini';
$lang['Active Languages'] = 'Aktif Diller';
$lang['Delete this language'] = 'Bu dili sil';
$lang['Forbid this language to users'] = 'Kullanıcılar için bu dili yasakla';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Bu dili devre dışı bırakmak imkansız, önce varsayılan olarak başka bir dil ayarla.';
$lang['Menu Management'] = 'Menü Yönetimi';
$lang['%d of %d photos selected'] = '%d resimden %d seçildi';
$lang['Action'] = 'Eylem';
$lang['Add a filter'] = 'Filtre ekle';
$lang['Album photos associated to the following albums: %s'] = 'Albüm fotoğrafları aşağıdaki albümlerle ilişkilendirildi: %s';
$lang['Albums automatically sorted'] = 'Albümler otomatik olarak sıralandı';
$lang['All %d photos are selected'] = 'Bütün %d resimler seçildi';
$lang['Apply action'] = 'Eylemi onayla';
$lang['automatic order'] = 'otomatik sıralama';
$lang['Batch Manager'] = 'Küme Yöneticisi';
$lang['Choose an action'] = 'Eylem seçiniz';
$lang['Delete orphan tags'] = 'etkisiz etiketleri sil';
$lang['delete photo'] = 'resimi sil';
$lang['duplicates'] = 'kopyalar';
$lang['include child albums'] = 'alt albümler dahil';
$lang['Keep high definition'] = 'Yüksek tanımlı tutun';
$lang['last import'] = 'son içe aktarma';
$lang['manual order'] = 'el ile düzen';
$lang['No photo in the current set.'] = 'bu sette resim yok.';
$lang['No photo selected, %d photos in current set'] = 'Resim seçilmedi, %d bu setteki resimler';
$lang['No photo selected, no action possible.'] = 'Resim seçilmedi, eylem imkansız.';
$lang['on the %d selected photos'] = '%ds resimler seçildi';
$lang['Orphan tags deleted'] = 'etkisiz etiketler silindi';
$lang['Plugins'] = 'Eklentiler';
$lang['predefined filter'] = 'filtre önceden tanımlanmış';
$lang['Refresh photo set'] = 'Resim setini yenile';
$lang['Remove all filters'] = 'Tüm filtreleri sil';
$lang['remove author'] = 'yazarı sil';
$lang['remove creation date'] = 'oluşturulma tarihini sil';
$lang['remove this filter'] = 'Bu filtreyi sil';
$lang['remove title'] = 'başlığı sil';
$lang['Selection'] = 'Seçim';
$lang['Set author'] = 'Yazar ayarla';
$lang['Set creation date'] = 'oluşturma tarihi ayarla';
$lang['Set title'] = 'Başlığı ayarla';
$lang['The high definition image quality must be a number between %d and %d'] = 'yüksek tanımlı resim kalitesi %d ve %d arasında bir sayı olmalıdır';
$lang['The high definition maximum height must be a number between %d and %d'] = 'yüksek tanımlı resim yüksekliği %d ve %d arasında bir sayı olmalıdır';
$lang['The high definition maximum width must be a number between %d and %d'] = 'yüksek tanımlı resim genişliği %d ve %d arasında bir sayı olmalıdır';
$lang['The whole page'] = 'Bütün sayfa';
$lang['The whole set'] = 'Bütün set';
$lang['Type here the author name'] = 'Yazar adını buraya yazın';
$lang['Type here the title'] = 'Başlığı buraya yazın';
$lang['Week starts on'] = 'Hafta başlangıcı';
$lang['with no album'] = 'sıfır albüm ile';
$lang['with no tag'] = 'sıfır etiket ile';
$lang['with no virtual album'] = 'sıfır sanal albüm ile';
$lang['You have %d orphan tags: %s.'] = '%d etkisiz etiketleriniz: %s.';
$lang['Remove from caddie'] = 'Yardımcıdan sil';
$lang['Themes which need upgrade'] = 'Güncellenmesi gereken temalar';
$lang['Languages which need upgrade'] = 'Güncellenmesi gereken diller';
$lang['All themes are up to date.'] = 'Bütün temalar güncel.';
$lang['All plugins are up to date.'] = 'Bütün eklentiler güncel.';
$lang['All languages are up to date.'] = 'Bütün diller güncel.';
$lang['Visit theme site'] = 'Tema sitesine git';
$lang['Visit language site'] = 'Dil sitesine git';
$lang['New Version'] = 'Yeni Versiyon';
$lang['Obsolete Plugins'] = 'Eski Eklentiler';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'UYARI! Bu eklenti Piwigo galerinizin bu versiyonu ile uyumlu değildir.';
$lang['Do you want to activate anyway?'] = 'Yine de etkinleştirmek istiyor musunuz?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'Bu eklenti şimdi Piwigo\'nun kendi parçasıdır lütfen siliniz.!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'Hata: Bu eklenti eksik, ama yüklenmiş. Lütfen siliniz.';
$lang['Restore'] = 'Onarım';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Varsayılan yapılandırmalarınızı onarın. Eklenti ayarlrınız kaybolacaktır!';
$lang['display'] = 'göster';
$lang['Regenerate Thumbnails'] = 'Küçük Resimleri Tekrar Oluştur';
$lang['Thumbnails generation in progress...'] = 'Küçük resimler oluşturuluyor...';
$lang['%s thumbnails have been regenerated'] = '%s küçük resimler oluşturuldu';
$lang['%s thumbnails can not be regenerated'] = '%s küçük resimler oluşturulamadı';
$lang['Regenerate Websize Photos'] = 'Yeniden web boyutu oluştur';
$lang['Photos generation in progress...'] = 'Resimler oluşturulmaya devam ediyor...';
$lang['%s photos have been regenerated'] = '%s resimler oluşturuldu';
$lang['%s photos can not be regenerated'] = '%s resimler oluşturulamadı';
$lang['new'] = 'yeni';
$lang['No results'] = 'Sonuç yok';
$lang['Searching...'] = 'Arıyor...';
$lang['Type in a search term'] = 'Aramak için bir kelime yazınız';
$lang['Deactivate all'] = 'Hepsini etkisizleştir';
$lang['Show menubar'] = 'menü çubuğunu göster';
$lang['Updates'] = 'Güncellemeler';
$lang['Update in progress... Please wait.'] = 'Güncelleniyor.. Lütfen bekleyiniz.';
$lang['Ignore this update'] = 'Bu güncellemeyi görmezden gel';
$lang['Reset ignored updates'] = 'Görmezden gelinen güncellemeleri tekrar ayarla';
$lang['Update All'] = 'Hepsini Güncelle';
$lang['ERROR'] = 'HATA';
$lang['Update Complete'] = 'Güncelleme Tamamlandı';
$lang['Piwigo Update'] = 'Piwigo Güncellemesi';
$lang['Extensions Update'] = 'Eklentiler Güncellemesi';
$lang['All extensions are up to date.'] = 'Tüm eklentiler günceldir.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Aşağıdaki eklentiler Piwigo yeni sürümü ile uyumlu olmayabilir:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Aşağıdaki temalar Piwigo yeni sürümü ile uyumlu olmayabilir:';
$lang['I decide to update anyway'] = 'Güncellemeye karar verdim';
$lang['Update to Piwigo %s'] = 'Piwigoyu %s\'e güncelle';
$lang['Two updates are available'] = 'İki güncelleştirme mevcut';
$lang['This is a minor update, with only bug corrections.'] = 'Bu sadece hata düzeltmeleri ile, küçük bir güncelleştirme.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Bu yeni büyük bir güncelleme <a href="%s">yeni heyecan verici özellikler</a> içerir.';
$lang['Some themes and plugins may be not available yet.'] = 'Bazı tema ve eklentiler henüz hazır olamayabilir.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Piwigoyu direkt olarak %s\'e güncelleyebilirsiniz, Piwigo %s\'e güncellemeden (önerilir).';
$lang['Save Template Directory'] = 'Tema dizinini kaydet';
$lang['Dump Database'] = 'Vertitabanını sil';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Geçmiş verileri dahil et (UYARI: sunucu belleği sınırı aşılabilir)';
$lang['Unable to write new local directory.'] = 'Yeni bir yerel dizine yazılamıyor.';
$lang['Unable to send template directory.'] = 'Tema dizinine gönderilemiyor.';
$lang['Unable to dump database.'] = 'Veritabanı silinemiyor.';
$lang['Some upgrades are available for extensions.'] = 'Eklentiler için bazı güncellemeler mevcut.';
$lang['Ignore All'] = 'Tümünü Yoksay';
$lang['Crop'] = 'Kes';
$lang['Width'] = 'Genişlik';
$lang['Height'] = 'Yükseklik';
$lang['Follow Orientation'] = 'Oryantasyonu takip edin';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Eğer küçük resimleri yenilemek istiyorsanız, <a href="%s">Küçük Resimleri Tekrar Oluştur</a> gidin.';
$lang['Graphics Library'] = 'Grafik Arşivi';
$lang['Activate icon "new" next to albums and pictures'] = 'Resimlerin yanındaki "yeni" simgesini etkinleştir';
$lang['Default photos order'] = 'Varsayılan resim düzeni';
$lang['Learn more'] = 'Daha fazla bilgi edinin';
$lang['Average rate'] = 'Ortalama derecelendirme';
$lang['Rate'] = 'Oyla';
$lang['... or '] = '... yada';
$lang['Create'] = 'Oluştur';
$lang['hide details'] = 'ayrıntıları gizle';
$lang['Select an album'] = 'Albüm seçiniz';
$lang['show details'] = 'ayrıntıları göster';
$lang['Start Upload'] = 'Yüklemeye başla';
?>